@@ -4,7 +4,7 @@
 #if !defined(LTTNG_TRACE_PRINTK_H) || defined(TRACE_HEADER_MULTI_READ)
 #define LTTNG_TRACE_PRINTK_H
 
-#include "../../../probes/lttng-tracepoint-event.h"
+#include <probes/lttng-tracepoint-event.h>
 #include <linux/version.h>
 
 #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,10,0))
@@ -72,4 +72,4 @@ LTTNG_TRACEPOINT_EVENT_MAP(console,
 #endif /* LTTNG_TRACE_PRINTK_H */
 
 /* This part must be outside protection */
-#include "../../../probes/define_trace.h"
+#include <probes/define_trace.h>
