@@ -169,7 +169,7 @@ size_t lib_ring_buffer_do_strcpy(const struct lib_ring_buffer_config *config,
 		 * Only read source character once, in case it is
 		 * modified concurrently.
 		 */
-		c = ACCESS_ONCE(src[count]);
+		c = READ_ONCE(src[count]);
 		if (!c)
 			break;
 		lib_ring_buffer_do_copy(config, &dest[count], &c, 1);
