@@ -22,8 +22,8 @@
 
 #include <linux/module.h>
 #include <linux/kvm_host.h>
-#include "../lttng-tracer.h"
-#include "../lttng-kernel-version.h"
+#include <lttng-tracer.h>
+#include <lttng-kernel-version.h>
 
 #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,1,0))
 #include <kvm/iodev.h>
@@ -37,7 +37,7 @@
  */
 #include <trace/events/kvm.h>
 
-#include "../wrapper/tracepoint.h"
+#include <wrapper/tracepoint.h>
 
 /*
  * Create LTTng tracepoint probes.
@@ -45,8 +45,8 @@
 #define LTTNG_PACKAGE_BUILD
 #define CREATE_TRACE_POINTS
 
-#define TRACE_INCLUDE_PATH ../instrumentation/events/lttng-module/arch/x86/kvm
-#include "../instrumentation/events/lttng-module/arch/x86/kvm/trace.h"
+#define TRACE_INCLUDE_PATH instrumentation/events/lttng-module/arch/x86/kvm
+#include <instrumentation/events/lttng-module/arch/x86/kvm/trace.h>
 
 MODULE_LICENSE("GPL and additional rights");
 MODULE_AUTHOR("Mathieu Desnoyers <mathieu.desnoyers@efficios.com>");
