@@ -31,8 +31,12 @@
 long lttng_strlen_user_inatomic(const char *addr)
 {
 	long count = 0;
-	mm_segment_t old_fs = get_fs();
+	mm_segment_t old_fs;
 
+	if (!addr)
+		return 0;
+
+	old_fs = get_fs();
 	set_fs(KERNEL_DS);
 	pagefault_disable();
 	for (;;) {
