@@ -24,7 +24,7 @@
 #include <linux/module.h>
 #include <linux/videodev2.h>
 #include <media/videobuf2-core.h>
-#include "../lttng-tracer.h"
+#include <lttng-tracer.h>
 /*
  * Create the tracepoint static inlines from the kernel to validate that our
  * trace event macros match the kernel we run on.
@@ -36,9 +36,9 @@
  */
 #define LTTNG_PACKAGE_BUILD
 #define CREATE_TRACE_POINTS
-#define TRACE_INCLUDE_PATH ../instrumentation/events/lttng-module
+#define TRACE_INCLUDE_PATH instrumentation/events/lttng-module
 
-#include "../instrumentation/events/lttng-module/v4l2.h"
+#include <instrumentation/events/lttng-module/v4l2.h>
 
 MODULE_LICENSE("GPL and additional rights");
 MODULE_AUTHOR("Wade Farnsworth <wade_farnsworth@mentor.com>");
